Report

Struct Report 

pub struct Report {
    pub name: String,
    pub hosts: ReportHosts,
}
The Report format. The report is broken down into a list of hosts, each of which has an associated list of findings.

Fields

name: String

Name of the report

hosts: ReportHosts

Holds a Vec of ReportHosts

Implementations

Source

impl Report

pub fn parse(node: &Node<'_, '_>) -> Result<Self, Error>

Builds a Report object from an XML node