pub struct Report {
pub name: String,
pub hosts: ReportHosts,
}Expand description
The Report format. The report is broken down into a list of hosts, each of which has an associated list of findings.
Fields
name: StringName of the report
hosts: ReportHostsHolds a Vec of ReportHosts
Implementations